atomate.qchem.workflows.tests package — atomate 0.9.2 documentation

# atomate.qchem.workflows.tests package

## Submodules

## atomate.qchem.workflows.tests.test_double_FF_opt module

class `atomate.qchem.workflows.tests.test_double_FF_opt.` `TestDoubleFFOpt`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_double_FF_opt`()

## atomate.qchem.workflows.tests.test_fragmentation module

class `atomate.qchem.workflows.tests.test_fragmentation.` `TestFragmentation`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_Fragmentation`()
  `test_no_opt_Fragmentation`()

## atomate.qchem.workflows.tests.test_parse_pass_write module

class `atomate.qchem.workflows.tests.test_parse_pass_write.` `TestParsePassWrite`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `tearDown`()

    Remove the scratch directory and teardown the test db.

  `test_parse_pass_rotate_write`()
  `test_parse_pass_write`()

## atomate.qchem.workflows.tests.test_torsion_potential module

class `atomate.qchem.workflows.tests.test_torsion_potential.` `TestTorsionPotential`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_torsion_potential`()

## Module contents